@@ -1,26 +1,28 @@
-#!/usr/bin/perl
+#!/usr/bin/perl -w
 #
 #
 # A Net::DRI example
-# See also t/Net/DRI/Protocol/EPP/Extensions/EURid.t
+# See also t/606eurid_epp.t
 
-use utf8;
 use strict;
-use warnings;
 
 use Net::DRI;
+use Net::DRI::Data::Hosts;
+use Net::DRI::Data::ContactSet;
 
+use DateTime::Duration;
+ 
 my $CLID='YOUR TEST CLIENT ID'; ### Change this information
 my $PASS='YOUR PASSWORD'; ### Change this information
 
-my $dri=Net::DRI->new({cache_ttl=>10,logging=>'files'});
+my $dri=Net::DRI->new(10);
 
-my $ok=eval {
+eval {
 ############################################################################################################
 $dri->add_registry('EURid',{clid=>$CLID});
 
-## This connects to .EU server for tests
-my $rc=$dri->target('EURid')->add_current_profile('profile1','epp',{client_login=>$CLID,client_password=>$PASS});
+## This connects to .EU OT&E server
+my $rc=$dri->target('EURid')->new_current_profile('profile1','Net::DRI::Transport::Socket',[{log_fh=>\*STDERR,defer=>0,socktype=>'ssl',remote_host=>'epp.registry.tryout.eu',remote_port=>33123,ssl_key_file=>'privkey.pem',ssl_cert_file=>'cacert.pem',ssl_ca_file=>'cacert.pem',ssl_cipher_list=>'TLSv1',protocol_connection=>'Net::DRI::Protocol::EPP::Connection',protocol_version=>1,client_login=>$CLID,client_password=>$PASS}],'Net::DRI::Protocol::EPP::Extensions::EURid',['1.0',['Net::DRI::Protocol::EPP::Extensions::EURid::Sunrise']]);
 
 die($rc) unless $rc->is_success(); ## Here we catch all errors during setup of transport, such as authentication errors
 
@@ -47,12 +49,12 @@ $c3->srid($id);
 my $dom='toto-'.time().'.eu';
 $rc=$dri->domain_check($dom);
 print "$dom does not exist\n" unless $dri->get_info('exist');
-my $cs=$dri->local_object('contactset');
+my $cs=Net::DRI::Data::ContactSet->new();
 $cs->set($c1,'registrant');
 $cs->set($c2,'billing');
 $cs->set($c3,'tech');
 print "Attempting to create domain $dom\n";
-$rc=$dri->domain_create($dom,{pure_create=>1,duration=>$dri->local_object('duration',years => 1),ns=>$dri->local_object('hosts')->set('ns.example.com'),contact=>$cs});
+$rc=$dri->domain_create_only($dom,{duration=>DateTime::Duration->new(years =>1),ns=>Net::DRI::Data::Hosts->new->add('ns.example.com'),contact=>$cs});
 print "$dom created\n" if $rc->is_success();
 
 ## After the domain:create, the connection is dropped by the server
@@ -64,10 +66,10 @@ $rc=$dri->domain_info($dom);
 print "domain_info OK\n" if $rc->is_success();
 
 my $ns='ns.titi-'.time().'.fr';
-my $nso=$dri->local_object('hosts')->set($ns);
+my $nso=Net::DRI::Data::Hosts->new($ns);
 print "NS=$ns\n";
 
-if ($dri->has_object('ns')) ## Should be false for EURid
+if ($dri->has_object('host')) ## Should be false for EURid
 {
  my $e=$dri->host_exist($ns);
  print "Host exist\n" if ($e==1);
@@ -87,7 +89,7 @@ print "ns_del OK\n" if $rc->is_success();
 $rc=$dri->domain_info($dom);
 
 # No domain status handling in EURid
-#my $s=$dri->local_object('status')->no('update');
+#my $s=$dri->create_status()->no('update');
 #$rc=$dri->domain_update_status_add($dom,$s);
 #print "status_add OK\n" if $rc->is_success();
 #$rc=$dri->domain_info($dom);
@@ -95,7 +97,7 @@ $rc=$dri->domain_info($dom);
 #print "status_del OK\n" if $rc->is_success();
 #$rc=$dri->domain_info($dom);
 
-$rc=$dri->domain_delete($dom,{pure_delete => 1});
+$rc=$dri->domain_delete_only($dom);
 print "domain_delete OK\n" if $rc->is_success();
 
 $rc=$dri->contact_delete($c1);
@@ -105,27 +107,25 @@ print "Contact2 deleted successfully" if $rc->is_success();
 $rc=$dri->contact_delete($c3);
 print "Contact3 deleted successfully" if $rc->is_success();
 
-
-$dri->end();
 };
 
-if (! $ok)
+if ($@)
 { 
- my $err=$@;
- print "\n\nAn EXCEPTION happened !\n";
- if (ref $err)
+ print "\n\nAN ERROR happened !!!\n";
+ if (ref($@))
  {
-  $err->print();
+  $@->print();
  } else
  {
-  print $err;
+  print($@);
  }
 } else
 {
- print "\n\nNo exception happened";
+ print "\n\nNo error";
 }
 
 print "\n";
+$dri->end();
 exit 0;
 
 ######################################################
